==> eelbrain-0.14.2.tar.gz: eelbrain-0.14.2/eelbrain/_wxutils/ID.py <==
'''
Created on Feb 26, 2012

@author: christian
'''

import wx

APYDOC_NEW = wx.NewId()
ATTACH = wx.NewId()

CANVAS_PANEL_ZOOM = wx.NewId()
CANVAS_PANEL_OVERVIEW = wx.NewId()
CLEAR_CACHE = wx.NewId()
CLEAR_TERMINAL = wx.NewId()
COLOUR_CHOOSER = wx.NewId()
COMMENT = wx.NewId()

DATASET_ATTACH = wx.NewId()
DATASET_IMPORT = wx.NewId()
DUPLICATE = wx.NewId()
DUPLICATE_WITH_OUTPUT = wx.NewId()

EXPERIMENT_LOAD = wx.NewId()
EXPERIMENT_NEW = wx.NewId()
ENABLE_STARTUP_SCRIPT = wx.NewId()
EXCLUDE_CHANNELS = wx.NewId()
EXEC_DOCUMENT = wx.NewId()
EXEC_DOCUMENT_FROM_DISK = wx.NewId()
EXEC_FILE = wx.NewId()
EXEC_SELECTION = wx.NewId()

FIG_TITLE = wx.NewId()
FOCUS_SHELL = wx.NewId()
FULLSCREEN = wx.NewId()

GRAND_AVERAGE = wx.NewId()

HELP_EELBRAIN = wx.NewId()
HELP_HIDE = wx.NewId()
HELP_MDP = wx.NewId()
HELP_MPL = wx.NewId()
HELP_PDB = wx.NewId()
HELP_PYTHON = wx.NewId()

INSERT_Color = wx.NewId()
INSERT_Path_file = wx.NewId()
INSERT_Path_dir = wx.NewId()
INSERT_Path_new = wx.NewId()

OPEN = wx.NewId()
OPEN_HISTORY = wx.NewId()
OPEN_HISTORY_CURRENT = wx.NewId()
OPEN_HISTORY_PAST = wx.NewId()

PLOT_RANGE = wx.NewId()
PYDOC_NEW = wx.NewId()
PYDOC_LOAD = wx.NewId()
PYDOC_EXEC_ISOLATE = wx.NewId()
PYDOC_HASH = wx.NewId()
PYPLOT_CLOSEALL = wx.NewId()
PYPLOT_DRAW = wx.NewId()

P_MGR = wx.NewId()
PCA_REMOVE = wx.NewId()

RECENT_LOAD_E = wx.NewId()
RECENT_LOAD_PYDOC = wx.NewId()
REDO = wx.NewId()
RESIZE = wx.NewId()

SAVE_REJECTION = wx.NewId()
SET_BAD_CHANNELS = wx.NewId()
SET_FONT = wx.NewId()
SET_LAYOUT = wx.NewId()
SET_TEND = wx.NewId()
SET_TSTART = wx.NewId()
SET_VLIM = wx.NewId()
SHELL_Clear = wx.NewId()
SHOW_EXAMPLES = wx.NewId()
SHOW_SOURCE = wx.NewId()
SIZE_MAX = wx.NewId()
SIZE_MAX_NOTITLE = wx.NewId()
SIZE_MIN = wx.NewId()
SPLITTER = wx.NewId()
SPLITTER2 = wx.NewId()

TABLE = wx.NewId()
TABLE_COL = wx.NewId()
TABLE_ROW = wx.NewId()
TABLE_SAVE = wx.NewId()
THRESHOLD = wx.NewId()

UNDO = wx.NewId()

WINDOW_MINIMIZE = wx.NewId()
WINDOW_ZOOM = wx.NewId()

YIELD_TO_TERMINAL = wx.NewId()

==> eelbrain-0.20.7.tar.gz: eelbrain-0.20.7/eelbrain/_wxutils/ID.py <==
'''
Created on Feb 26, 2012

@author: christian
'''

import wx

APYDOC_NEW = wx.NewId()
ATTACH = wx.NewId()

CANVAS_PANEL_ZOOM = wx.NewId()
CANVAS_PANEL_OVERVIEW = wx.NewId()
CLEAR_CACHE = wx.NewId()
CLEAR_TERMINAL = wx.NewId()
COLOUR_CHOOSER = wx.NewId()
COMMENT = wx.NewId()

DATASET_ATTACH = wx.NewId()
DATASET_IMPORT = wx.NewId()
DUPLICATE = wx.NewId()
DUPLICATE_WITH_OUTPUT = wx.NewId()

EXPERIMENT_LOAD = wx.NewId()
EXPERIMENT_NEW = wx.NewId()
ENABLE_STARTUP_SCRIPT = wx.NewId()
EXEC_DOCUMENT = wx.NewId()
EXEC_DOCUMENT_FROM_DISK = wx.NewId()
EXEC_FILE = wx.NewId()
EXEC_SELECTION = wx.NewId()

FIG_TITLE = wx.NewId()
FOCUS_SHELL = wx.NewId()

GRAND_AVERAGE = wx.NewId()

HELP_EELBRAIN = wx.NewId()
HELP_HIDE = wx.NewId()
HELP_MDP = wx.NewId()
HELP_MPL = wx.NewId()
HELP_PDB = wx.NewId()
HELP_PYTHON = wx.NewId()

INSERT_Color = wx.NewId()
INSERT_Path_file = wx.NewId()
INSERT_Path_dir = wx.NewId()
INSERT_Path_new = wx.NewId()

OPEN = wx.NewId()
OPEN_HISTORY = wx.NewId()
OPEN_HISTORY_CURRENT = wx.NewId()
OPEN_HISTORY_PAST = wx.NewId()

PYDOC_NEW = wx.NewId()
PYDOC_LOAD = wx.NewId()
PYDOC_EXEC_ISOLATE = wx.NewId()
PYDOC_HASH = wx.NewId()
PYPLOT_CLOSEALL = wx.NewId()
PYPLOT_DRAW = wx.NewId()

P_MGR = wx.NewId()
PCA_REMOVE = wx.NewId()

RECENT_LOAD_E = wx.NewId()
RECENT_LOAD_PYDOC = wx.NewId()
REDO = wx.NewId()
RESIZE = wx.NewId()

SAVE_REJECTION = wx.NewId()
SET_BAD_CHANNELS = wx.NewId()
SET_FONT = wx.NewId()
SET_LAYOUT = wx.NewId()
SET_MARKED_CHANNELS = wx.NewId()
SET_TEND = wx.NewId()
SET_TSTART = wx.NewId()
SET_VLIM = wx.NewId()
SHELL_Clear = wx.NewId()
SHOW_EXAMPLES = wx.NewId()
SHOW_SOURCE = wx.NewId()
SIZE_MAX = wx.NewId()
SIZE_MAX_NOTITLE = wx.NewId()
SIZE_MIN = wx.NewId()
SPLITTER = wx.NewId()
SPLITTER2 = wx.NewId()

TABLE = wx.NewId()
TABLE_COL = wx.NewId()
TABLE_ROW = wx.NewId()
TABLE_SAVE = wx.NewId()
THRESHOLD = wx.NewId()

UNDO = wx.NewId()

WINDOW_MINIMIZE = wx.NewId()
WINDOW_TILE = wx.NewId()
WINDOW_ZOOM = wx.NewId()

YIELD_TO_TERMINAL = wx.NewId()
